@@ -10,13 +10,6 @@ multigrps <-
            minfactorlevels=10,
            sim=FALSE,
            workspace=2e5,ShowStatistic = F){
-    #df must be a data.frame object; tibble is not allowed
-    df <- data.frame(df)
-    # NA variables in gvar must be removed
-    if(sum(is.na(df[,gvar]))!=0){
-      df <- df[!is.na(df[,gvar]),]
-      warning( "gvar contains missing values; rows with missing gvar removed" )
-    }
     ##group varibale must be a factor
     df[,gvar]<-as.factor(df[,gvar])
     #NaN is forced to be NA, NaN can cause problem
@@ -88,7 +81,7 @@ multigrps <-
           rownames(tabGrp) <- rownames(table.sub)
           table1 <- data.frame("Variables" = paste("  ",levels(df[,var]),sep = ""),
                                paste(as.data.frame(tableTol)[,"Freq"]," (",
-                                     format(round(as.data.frame(per)[,"Freq"]*100,cat.rd),nsmall = cat.rd),
+                                     round(as.data.frame(per)[,"Freq"]*100,cat.rd),
                                      ")",sep = ""),stringsAsFactors = F)
           table1 <- cbind(table1,tabGrp,p=" ",statistic=" ")
           table1 <- apply(table1, 2,as.character)
@@ -111,9 +104,9 @@ multigrps <-
             tabGrp<-NULL
             nameGrp <- NULL
             for(varGrp in levels(df[,gvar])){
-              tabGrp1 <- paste(format(round(mean(df[df[,gvar]==varGrp,var],na.rm=T),norm.rd),nsmall = norm.rd),
+              tabGrp1 <- paste(round(mean(df[df[,gvar]==varGrp,var],na.rm=T),norm.rd),
                                " \U00B1 ",
-                               format(round(sd(df[df[,gvar]==varGrp,var],na.rm=T),norm.rd),nsmall = norm.rd),
+                               round(sd(df[df[,gvar]==varGrp,var],na.rm=T),norm.rd),
                                sep = "")
               nameGrp1 <- paste(varGrp," (","n = ",table(df[,gvar])[varGrp],")",sep = "")
               tabGrp <- cbind(tabGrp,tabGrp1)
@@ -124,14 +117,13 @@ multigrps <-
             p<-summary(aov(df[,var]~df[,gvar]))[[1]][1,"Pr(>F)"]
             statistic <- summary(aov(df[,var]~df[,gvar]))[[1]][1,"F value"]
             table1 <- data.frame(paste(var,", Mean"," \U00B1 ","SD",sep = ""),
-                                 paste(format(round(mean(df[,var],na.rm=T),norm.rd),nsmall = norm.rd),
+                                 paste(round(mean(df[,var],na.rm=T),norm.rd),
                                        " \U00B1 ",
-                                       format(round(sd(df[,var],na.rm=T),norm.rd),nsmall = norm.rd),
-                                       sep = ""),
+                                       round(sd(df[,var],na.rm=T),norm.rd),sep = ""),
                                  tabGrp,
                                  ifelse(p<1*10^(-p.rd),
                                         paste("< ",1*10^(-p.rd),sep = ""),
-                                        format(round(p,p.rd),nsmall=p.rd)),
+                                        round(p,p.rd)),
                                  round(statistic,3),stringsAsFactors = F)
             colnames(table1)<-c("Variables",
                                 paste("Total (n = ",nrow(df),")",sep = ""),
@@ -146,12 +138,10 @@ multigrps <-
             tabGrp<-NULL
             nameGrp <- NULL
             for(varGrp in levels(df[,gvar])){
-              tabGrp1 <- paste(format(round(summary(df[df[,gvar]==varGrp,var])[3],sk.rd),nsmall = sk.rd),
+              tabGrp1 <- paste(round(summary(df[df[,gvar]==varGrp,var])[3],sk.rd),
                                " (",
-                               format(round(summary(df[df[,gvar]==varGrp,var])[2],sk.rd),nsmall = sk.rd),
-                               ", ",
-                               format(round(summary(df[df[,gvar]==varGrp,var])[5],sk.rd),nsmall = sk.rd),
-                                      ")",
+                               round(summary(df[df[,gvar]==varGrp,var])[2],sk.rd),", ",
+                               round(summary(df[df[,gvar]==varGrp,var])[5],sk.rd),")",
                                sep = "")
               nameGrp1 <- paste(varGrp," (","n = ",table(df[,gvar])[varGrp],")",sep = "")
               tabGrp <- cbind(tabGrp,tabGrp1)
@@ -159,14 +149,13 @@ multigrps <-
             }		
             p<-kruskal.test(df[,var]~df[,gvar])$p.value
             statistic <- kruskal.test(df[,var]~df[,gvar])$statistic
-            table1 <- data.frame(paste(var,", Median"," (IQR)",sep = ""),
-                                 paste(format(round(median,sk.rd),nsmall = sk.rd)," (",
-                                       format(round(IQR1,sk.rd),nsmall = sk.rd),", ",
-                                       format(round(IQR3,sk.rd),nsmall = sk.rd),")",sep = ""),
+            table1 <- data.frame(paste(var,", Median"," (Q1,Q3)",sep = ""),
+                                 paste(round(median,sk.rd)," (",round(IQR1,sk.rd),", ",
+                                       round(IQR3,sk.rd),")",sep = ""),
                                  tabGrp,
                                  ifelse(p<1*10^(-p.rd),
                                         paste("< ",1*10^(-p.rd),sep = ""),
-                                        format(round(p,p.rd),nsmall = p.rd)),
+                                        round(p,p.rd)),
                                  round(statistic,3),stringsAsFactors = F)
             colnames(table1)<-c("Variables",
                                 paste("Total (n = ",nrow(df),")",sep = ""),
